package com.mist;
//Imports
import android.app.ListActivity;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.widget.ArrayAdapter;
import android.widget.ListView;

import com.mist.database.FilterSQL;
import com.mist.utils.Constants;

/**
 * Projecte MIST
 * 
 * Treball de final de carrera. Enginyeria Tcnica en Informtica de Sistemes
 * Universitat Oberta de Catalunya
 * 
 * @Author Alejandro Garca Rodrguez
 * @version Android 1.6, 2.1, 2.2
 * 
 * @description Activitat dintre de les TABS que mostra el llistat de filtres
 * 				Hereta de {@link}ListActivity per facilitat alhora de mostrar les dades de forma automtica 
 */
public class ListFilterTab extends ListActivity{

	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		//setContentView(R.layout.filter_list);

		//Pintem la llista
		paintList();
	}

	/**
	 * Mtode privat que recupera la llista de filtres y construeix el Adapter de tipus List per pintar el layout
	 */
	private void paintList(){
		FilterSQL sql = new FilterSQL(getApplicationContext());
		
		//Recuperem les accions fins ara de la base de dades
		String[] values = sql.getFilters();
		
		setListAdapter(new ArrayAdapter<String>(getApplicationContext(), R.layout.filter_list, values));

		ListView lv = getListView();
		lv.setTextFilterEnabled(true);
	}
	
	private void refresh(){
		//Tornem a re-pintar la llista
		paintList();
	}

	//Genera el men
	@Override
	public boolean onCreateOptionsMenu(Menu menu){
		super.onCreateOptionsMenu(menu);
		MenuInflater inflater = getMenuInflater();
		inflater.inflate(R.menu.menu_list, menu);
		return true;
	}

	/**
	 * Funci que captura l'item seleccionat del menu 
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item){
		switch(item.getItemId()){
		case R.id.refresh:
			refresh();
			return true;
		
		case R.id.drop:
			FilterSQL sql = new FilterSQL(getApplicationContext());
			sql.deleteTableFilters();
			
			//Al buidar la base de dades, guardem aquest fet per tornar-la a omplir al reiniciar l'aplicaci
			SharedPreferences prefs = getSharedPreferences( Constants.FILE_PREFS_NAME, MODE_PRIVATE);
			Editor editor = prefs.edit();
			editor.putBoolean(Constants.FILLED_DATABASE, false);
			editor.commit();
			
			//Refresquem el llistat
			refresh();
			return true;
		}
		return false;
	}

}
