package com.mist;
//Imports
import com.mist.database.FilterSQL;
import com.mist.utils.Constants;
import com.mist.utils.Prefs;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;


/**
 * Projecte MIST
 * 
 * Treball de final de carrera. Enginyeria Tcnica en Informtica de Sistemes
 * Universitat Oberta de Catalunya
 * 
 * @Author Alejandro Garca Rodrguez
 * @version Android 1.6, 2.1, 2.2
 * 
 * @description Activitat principal d'entrada a l'aplicaci. Mostra la pantalla inicial
 */
public class Main extends Activity {
    
	static final int INFO_DIALOG_ID = 1;
	
	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
       
       if(Prefs.getIsDefault(this)){
	        //Recuperem de l'arxiu de preferencies si la base de dades esta generada
	       boolean filled = getPreference(Constants.FILLED_DATABASE);
	        if(!filled) {
	        	FilterSQL db = new FilterSQL(getApplicationContext());
	        	boolean result = db.fillFiltersDefault(this);
	        	
	        	if(!result){
	        		Log.w(Constants.TAG, getResources().getString(R.string.db_create_fail));
	        	}else{
	        		Log.w(Constants.TAG, getResources().getString(R.string.db_create_ok));
	        	}
	        //Guardem el resultat 	
	        savePreference(Constants.FILLED_DATABASE, result);
	        }
		}
        //Marquem que el filtre esta activat
        savePreference(Constants.FILTER_ACTIVATED, true);
    }
    
    /**
     * Funci del but "Afegir filtres"
     * @param View v
     */
  	public void add(View v) {
  		//startActivity(new Intent(this, AddFilterTab.class));
  		startActivity(new Intent(getApplicationContext(), FilterManagerTab.class));
  	}
  	
  	/**
  	 * Funci del but "Llistat tots els filtres"
  	 */
  	public void listFilters(View v){
		startActivity( new Intent(getApplicationContext(), ListFilterTab.class) );
	}
  	
  	 /**
     * Funci del but "Veure llistat"
     * @param View v
     */
  	public void listBlocked(View v) {
  		startActivity(new Intent(getApplicationContext(), ListBlocked.class));
  	}

   
	/**
	 * Funci que construeix els components dialeg.
	 */
	@Override
    protected Dialog onCreateDialog(int id) {
		AlertDialog.Builder builder;
    	AlertDialog alertDialog;
    	Context mContext = getApplicationContext();
    	
    	LayoutInflater inflater = (LayoutInflater) mContext.getSystemService(LAYOUT_INFLATER_SERVICE);
    	
    	switch (id) {
        
        case INFO_DIALOG_ID:
        	View layout_info = inflater.inflate(R.layout.info,
        	                               (ViewGroup) findViewById(R.id.layout_info));

        	TextView infoText = (TextView) layout_info.findViewById(R.id.info_text);
        	infoText.setText(R.string.info_text);
        	TextView infoText2 = (TextView) layout_info.findViewById(R.id.info_text2);
        	infoText2.setText(R.string.info_text2);
        	        	
        	builder = new AlertDialog.Builder(this);
        	builder.setView(layout_info);
        	alertDialog = builder.create();
        	alertDialog.setTitle(R.string.info_title);
        	return alertDialog;
        
        default:
        	return null;
        }
	}
	
	//Genera el men
	@Override
	public boolean onCreateOptionsMenu(Menu menu){
		super.onCreateOptionsMenu(menu);
		MenuInflater inflater = getMenuInflater();
		inflater.inflate(R.menu.menu, menu);
		return true;
	}
	
	/**
	 * Funci que captura l'item seleccionat del menu 
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item){
		switch(item.getItemId()){
		case R.id.more:
			showDialog(INFO_DIALOG_ID);
			return true;
		case R.id.settings:
			startActivity(new Intent(getApplicationContext(), Prefs.class));
			return true;
		}
		return false;
	}
	
	/*
	 * Finalizamos la app
	 * @param v
	 */
	public void end(View v){
		super.finish();
	}
	
	
	/**
	 * Funci interna per guardar una preferencia al arxiu de preferencies
	 * @param value
	 */
	public void savePreference(String name, boolean value){
		SharedPreferences settings = getSharedPreferences( Constants.FILE_PREFS_NAME , MODE_PRIVATE);
		
		 Editor editor = settings.edit();
	     editor.putBoolean(name, value);
	     editor.commit();
	}
	
	/**
	 * Funci interna per recuperar una preferencia de l'arxiu de preferencies
	 * @param preference
	 * @return
	 */
	public boolean getPreference(String preference){
		SharedPreferences settings = getPreferences(MODE_PRIVATE);
		
		return settings.getBoolean(preference, false);
	}
	
}