package com.mist.database;
//Imports
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import com.mist.database.dto.ActionDTO;
import com.mist.database.dto.FilterDTO;
import com.mist.filter.FilterCall;
import com.mist.filter.FilterSMS;
import com.mist.utils.Constants;

/**
 * Projecte MIST
 * 
 * Treball de final de carrera. Enginyeria Tcnica en Informtica de Sistemes
 * Universitat Oberta de Catalunya
 * 
 * @Author Alejandro Garca Rodrguez
 * @version Android 1.6, 2.1, 2.2
 * 
 * @description Classe DAO per guardar/recuperar/esborrar dades de la base de dades SQLite
 */
public class FilterSQL extends SQLiteOpenHelper{


	/**
	 * Constructor
	 * @param context
	 */
	public FilterSQL(Context context) {
		super(context, Constants.DATABASE_NAME, null, Constants.DATABASE_VERSION);
	}

	/**
	 * Mtode per omplir la base de dades amb els filtres per defecte
	 * @param context
	 * @return
	 */
	public boolean fillFiltersDefault(Context context){

		for (int i=0; i < Constants.filterDefaultTelfs.length; i++){
			this.insertFilter(Constants.filterDefaultTelfs[i], FilterCall.FILTER_TYPE);
		}

		for (int i=0; i < Constants.filterDefaultSMS.length; i++){
			this.insertFilter(Constants.filterDefaultSMS[i], FilterSMS.FILTER_TYPE);
		}
		return true;
	}

	/**
	 * Mtode de creaci de la base de dades de filtres
	 */
	@Override
	public void onCreate(SQLiteDatabase db) {
		db.execSQL("CREATE TABLE " + Constants.TABLE_NAME + 
				" (" + Constants.TABLE_FIELD_ID + " integer primary key autoincrement,"+
				" " + Constants.TABLE_FIELD_NUM + " integer,"+
				" " + Constants.TABLE_FIELD_TYPE + " text)");

		db.execSQL("CREATE TABLE " + Constants.TABLE_NAME_LIST + 
				" (" + Constants.TABLE_FIELD_ID_LIST + " integer primary key autoincrement,"+
				" " + Constants.TABLE_FIELD_NUM_LIST + " integer,"+
				" " + Constants.TABLE_FIELD_TYPE_LIST + " text,"+
				" " + Constants.TABLE_FIELD_ACTION_LIST + " text,"+
				" " + Constants.TABLE_FIELD_TIME_LIST + " long)");
	}

	/**
	 * Mtode de actualitzaci 
	 */
	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		db.execSQL("DROP TABLE IF EXISTS " + Constants.TABLE_NAME);
		db.execSQL("DROP TABLE IF EXISTS " + Constants.TABLE_NAME_LIST);
		onCreate(db);
	}

	/**
	 * Mtode per esborrar tota la taula de filtres
	 */
	public void dropTableFilters(){
		SQLiteDatabase data = this.getWritableDatabase();
		data.execSQL("DROP TABLE IF EXISTS " + Constants.TABLE_NAME);
		data.close();
	}
	
	/**
	 * Mtode per esborrar tota la taula d'accions
	 */
	public void dropTableActions(){
		SQLiteDatabase data = this.getWritableDatabase();
		data.execSQL("DROP TABLE IF EXISTS " + Constants.TABLE_NAME_LIST);
		data.close();
	}
	
	/**
	 * Mtode per esborrar el contingut de la taula de filtres
	 */
	public void deleteTableFilters(){
		SQLiteDatabase data = this.getWritableDatabase();
		data.delete(Constants.TABLE_NAME, null, null);
		data.close();
	}
	
	/**
	 * Mtode per esborrar el contingut de la taula d'accions
	 */
	public void deleteTableActions(){
		SQLiteDatabase data = this.getWritableDatabase();
		data.delete(Constants.TABLE_NAME_LIST, null, null);
		data.close();
	}

	/**
	 * Mtode per inserir un nou filtre a la base de dades
	 * @param int - num - el nmero a filtrar
	 * @param String - type - si es de tipus sms o tel
	 * @return
	 */
	public long insertFilter(int num, String type){
		SQLiteDatabase data = this.getWritableDatabase();
		ContentValues cv = new ContentValues();
		cv.put(Constants.TABLE_FIELD_NUM, num);
		cv.put(Constants.TABLE_FIELD_TYPE, type);

		try {
			return data.insert(Constants.TABLE_NAME, null, cv);
		} finally  {
			data.close();
		} 
	}

	/**
	 * Mtode per inserir una nova acci
	 * @param int - num - el nmero a filtrar 
	 * @param String - type - si es de tipo sms o tel
	 * @return
	 */
	public long insertAction(int num, String type, String action){
		SQLiteDatabase data = this.getWritableDatabase();
		ContentValues cv = new ContentValues();
		cv.put(Constants.TABLE_FIELD_NUM_LIST, num);
		cv.put(Constants.TABLE_FIELD_TYPE_LIST, type);
		cv.put(Constants.TABLE_FIELD_ACTION_LIST, action);
		cv.put(Constants.TABLE_FIELD_TIME_LIST, System.currentTimeMillis());

		try {
			return data.insert(Constants.TABLE_NAME_LIST, null, cv);
		} finally  {
			data.close();
		} 
	}

	/**
	 * Mtode que retorna un array amb les accions fetes per pintar la llista
	 * @return
	 */
	public String[] getActions(){
		SQLiteDatabase data = this.getReadableDatabase();
		Cursor cursor = null;
		try {
			cursor =  data.query(Constants.TABLE_NAME_LIST, null, null, null, null, null, null);

			int indice = 0;
			String[] values = new String[cursor.getCount()];
			while(cursor.moveToNext()){
				//values[indice] = " --> " + cursor.getInt(1) + "  Tipus: " + cursor.getString(2) + " Action: " + cursor.getString(3).toUpperCase();
				values[indice] = "#" +cursor.getString(2).toUpperCase() + ": " + cursor.getInt(1) + "  ===> " + cursor.getString(3).toUpperCase();
				indice++;
			}
			return values;
		} finally  {
			cursor.close();
			data.close();
		}
	}

	/**
	 * Mtodo que devuelve un array con todos los filtros per pintar la llista
	 * @return String[]
	 */
	public String[] getFilters(){
		SQLiteDatabase data = this.getReadableDatabase();
		Cursor cursor = null;
		try {
			cursor =  data.query(Constants.TABLE_NAME, null, null, null, null, null, null);

			int indice = 0;
			String[] values = new String[cursor.getCount()];
			while(cursor.moveToNext()){
				values[indice] = " Nmero: " + cursor.getInt(1) + "  Tipus: " + cursor.getString(2);
				indice++;
			}
			//cursor.close();
			return values;
		} finally  {
			cursor.close();
			data.close();
		} 

	}

	/**
	 * Mtode que retorna un filtre
	 * @param num el numero de telefon filtrat
	 * @return
	 */
	public FilterDTO getFilter(int num, String type){
		SQLiteDatabase data = this.getReadableDatabase();
		Cursor cursor = null;
		FilterDTO filter = null;
		try {
			cursor =  data.query(Constants.TABLE_NAME, null, null, null, null, null, null);

			while(cursor.moveToNext()){
				if( (cursor.getInt(1) == num) && (cursor.getString(2).equals(type))){
					filter = new FilterDTO(cursor.getInt(1), cursor.getString(2));
				}
			}
			return filter;
		} finally  {
			cursor.close();
			data.close();
		} 

	}
	
	/**
	 * Mtode que retorna una action realitzada
	 * @param num el numero de telefon
	 * @return
	 */
	public ActionDTO getAction(int num){
		SQLiteDatabase data = this.getReadableDatabase();
		Cursor cursor = null;
		ActionDTO action = null;
		try {
			cursor =  data.query(Constants.TABLE_NAME_LIST, null, null, null, null, null, null);

			while(cursor.moveToNext()){
				if(cursor.getInt(1) == num){
					action = new ActionDTO(cursor.getInt(1), cursor.getString(2), cursor.getString(3));
				}
			}
			return action;
		} finally  {
			cursor.close();
			data.close();
		} 

	}

}
